@@ -10,7 +10,7 @@ if (is.null(argv) | length(argv)<1) {
 }
 
 ## adjust as necessary, see help('download.packages')
-repos <- "http://cran.us.r-project.org"  
+repos <- "http://cran.us.r-project.org"
 
 ## this makes sense on Debian where no packages touch /usr/local
 lib.loc <- "/usr/local/lib/R/site-library"
@@ -19,8 +19,8 @@ lib.loc <- "/usr/local/lib/R/site-library"
 #function (pkgs, lib, repos = getOption("repos"),
 #          contriburl = contrib.url(repos, type),
 #          method, available = NULL, destdir = NULL,
-#          installWithVers = FALSE, 
+#          installWithVers = FALSE,
 #          dependencies = FALSE, type = getOption("pkgType"),
-#          configure.args = character(0), 
-#          clean = FALSE) 
-install.packages(argv, lib.loc, repos, dependencies=TRUE)
+#          configure.args = character(0),
+#          clean = FALSE)
+install.packages(argv, lib.loc, repos)
