@@ -1,7 +1,7 @@
 ExcludeVars <- c("R_SESSION_TMPDIR","R_HISTFILE")
 IncludeVars <- Sys.getenv()
 IncludeVars <- IncludeVars[grep("^R_",names(IncludeVars),perl=TRUE)]
-cat("char *R_VARS[] = {\n")
+cat("const char *R_VARS[] = {\n")
 for (i in 1:length(IncludeVars)){
 	if (names(IncludeVars)[i] %in% ExcludeVars)
 		next
